from DataProcessor import DataProcessor
from DataRetriever import DataRetriever
from DataAnalyzer import DataAnalyzer
import logging
import os
import sys
os.environ['TF_CPP_MIN_LOG_LEVEL'] = '3'
logging.getLogger('tensorflow').setLevel(logging.FATAL)
import json
import pandas as pd
import numpy as np
from sklearn import preprocessing
from keras.models import Sequential,load_model
from keras.layers import Dense
from keras.layers import LSTM
from keras.optimizers import Adam
from keras.layers import Dropout
from keras.layers.core import Activation
import keras
from sklearn.metrics import mean_squared_error
from keras import regularizers,initializers
from keras.models import model_from_json

def main(processInstanceId: str, method: str):
    metrics = ['temperature', 'systolic', 'diastolic', 'pulse', 'spo2', 'weight']
    defaults = [36, 115, 75, 75, 98, 75]

    dr = DataRetriever(metrics)
    dfs = dr.loadDataFromDB('localhost', '8086', 'admin', 'G10m1R0m3', 'giomi')

    dp = DataProcessor(metrics, defaults)
    df = dp.applyPipeline(dfs)
    
    inputs = df[df['processInstanceId'] == processInstanceId]

    inputs = inputs[-3:]
    inputs = inputs[metrics]
    inputs = inputs.values.reshape(1, 3, 6)

    model = None

    if method == 'save':
        model = Sequential()
        model.add(LSTM(input_shape=(3, 6), units=40, return_sequences=False))
        model.add(Dense(units=11))
        model.add(Activation("softmax"))
        model.compile(loss='mean_squared_error', optimizer='rmsprop')

        jsonModel = model.to_json()
        with open('model.json', 'w') as jsonFile:
            jsonFile.write(jsonModel)
        
        model.save_weights('model.h5')
    else:
        readJson = None

        with open('model.json', 'r') as jsonFile:
            readJson = jsonFile.read()
        
        model = model_from_json(readJson)
        model.load_weights('model.h5')


    #model.summary()

    output = model.predict(inputs)
    print(json.dumps({
        "output": output[0].tolist()
    }))

if __name__ == '__main__':
    if len(sys.argv) != 3:
        print("Usage: python3 main.py <processInstanceId> <load|save>")
        exit()
    
    
    processInstanceId = sys.argv[1]
    method = sys.argv[2]

    if method not in ['load', 'save']:
        print("Usage: python3 main.py <processInstanceId> <load|save>")
        exit()
    
    main(processInstanceId, method)

    
