from DataProcessor import DataProcessor
from DataRetriever import DataRetriever
from DataAnalyzer import DataAnalyzer
import numpy as np
import sys
import json

def main(n_dimensions: int, n_clusters: int, processInstanceId: str, method: str):
    metrics = ['temperature', 'systolic', 'diastolic', 'pulse', 'spo2', 'weight']
    defaults = [36, 115, 75, 75, 98, 75]

    dr = DataRetriever(metrics)
    dfs = dr.loadDataFromDB('localhost', '8086', 'admin', 'G10m1R0m3', 'giomi')

    dp = DataProcessor(metrics, defaults)
    df = dp.applyPipeline(dfs)
    da = DataAnalyzer(n_dimensions, metrics)
    da.applyPCA(df)
    kmeans = da.applyKMeans(df, n_clusters)
    ax, plt = da.plot(df, kmeans.labels_, kmeans.cluster_centers_)

    method = True if method == 'cluster' else False

    # point = da.addPatientPoint(df, ax, processInstanceId, True, kmeans)
    da.addAllPatientPoints(df, ax, processInstanceId)
    #distance = kmeans.transform(point.reshape(1, -1))
    #normalizedDistance = (distance / np.linalg.norm(distance, ord=2, axis=1, keepdims=True))[0]
    # out = {
    #     "distances": normalizedDistance.tolist()
    # }

    #print(json.dumps(out))

    plt.savefig('/tmp/out.png')

if __name__ == '__main__':
    if len(sys.argv) != 5:
        print("Usage: python3 main.py <n_dimensions> <n_clusters> <processInstanceId> <method>")
        exit()
    
    n_dimensions = int(sys.argv[1])
    n_clusters = int(sys.argv[2])
    processInstanceId = sys.argv[3]
    method = sys.argv[4]

    if n_dimensions not in [2,3]:
        print("n_dimensions should be 2 or 3")
    elif n_clusters < 1:
        print("n_clusters should be at least 1")
    elif method not in ['cluster', 'last']:
        print("methods accepted: cluster, last")
    else:
        main(n_dimensions, n_clusters, processInstanceId, method)

    
